.. _developers-guide-index:

################################
The Matplotlib Developers' Guide
################################

.. htmlonly::

   :Release: |version|
   :Date: |today|

.. toctree::
   :maxdepth: 2

   coding_guide.rst
   portable_code.rst
   license.rst
   gitwash/index.rst
   testing.rst
   documenting_mpl.rst
   release_guide.rst
   transformations.rst
   add_new_projection.rst
